config.PchipInterpolator2D — DarkHistory documentation

# config.PchipInterpolator2D

class `config.` `PchipInterpolator2D`(coords_data, values_data, pri, sec)

  2D interpolation over PPPC4DMID raw data, using PCHIP method.

  Parameters: | pri : string Specifies primary annihilation channel. See below for list. sec : {‘elec’, ‘phot’} Specifies stable SM secondary to get the spectrum of.
  Attributes: | pri : string Specifies primary annihilation channel. See below for list. sec : {‘elec’, ‘phot’} Specifies stable SM secondary to get the spectrum of. get_val : function Returns the interpolation value at (mDM_in_GeV, log10(K/mDM)) where K is the kinetic energy of the secondary.

  Methods

  get_val |

  `__init__`(coords_data, values_data, pri, sec)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(coords_data, values_data, pri, sec) | Initialize self.
  `get_val`(mDM_in_GeV, log10x) |

#### Previous topic

config

#### Next topic

config.load_data

### This Page

Show Source